@@ -1,3 +1,4 @@
+from django.contrib.contenttypes.models import ContentType
 from django.core.validators import MinValueValidator
 from django.forms import (
     CharField,
@@ -11,7 +12,7 @@ from netbox.forms import (
     NetBoxModelImportForm,
     NetBoxModelForm,
 )
-from netbox_storage.models import Drive, StorageConfigurationDrive
+from netbox_storage.models import Drive, StorageConfigurationDrive, TemplateConfigurationDrive, LinuxDevice
 from utilities.forms import (
     CSVModelChoiceField,
     DynamicModelChoiceField,
@@ -100,9 +101,22 @@ class DriveCreateForm(NetBoxModelForm):
         )
 
     def save(self, *args, **kwargs):
-        print("Hello")
-        drive = super().save(*args, **kwargs)
-        StorageConfigurationDrive.objects.create(virtual_machine=self.cleaned_data['virtual_machine'], drive=drive)
+        if self.cleaned_data['virtual_machine']:
+            number_of_hard_drives = StorageConfigurationDrive.objects.filter(virtual_machine=self.cleaned_data['virtual_machine']).count() or 0
+            self.instance.identifier = f'Hard Drive {number_of_hard_drives + 1}'
+            drive = super().save(*args, **kwargs)
+            StorageConfigurationDrive.objects.create(virtual_machine=self.cleaned_data['virtual_machine'], drive=drive)
+        else:
+            number_of_hard_drives = TemplateConfigurationDrive.objects.filter(platform=self.cleaned_data['platform']).count() or 0
+            self.instance.identifier = f'Hard Drive {number_of_hard_drives + 1}'
+            drive = super().save(*args, **kwargs)
+            drive_type_pk = ContentType.objects.get(app_label='netbox_storage', model='drive').pk
+            LinuxDevice.objects.create(device=drive.device_name(),
+                                       type='Disk',
+                                       size=self.cleaned_data['size'],
+                                       object_id=drive.pk,
+                                       content_type_id=drive_type_pk)
+            TemplateConfigurationDrive.objects.create(platform=self.cleaned_data['platform'], drive=drive)
         return drive
 
 
