@@ -296,3 +296,72 @@ class VolumeSimpleForm(NetBoxModelForm):
         print(f"{self.cleaned_data['fs']}")
 
         return drive
+
+
+class PartitionSimpleForm(NetBoxModelForm):
+    drive = DynamicModelChoiceField(
+        queryset=Drive.objects.all(),
+        label="Drive",
+        widget=APISelect(
+            attrs={"data-url": reverse_lazy("plugins-api:netbox_storage-api:drive-list")}
+        ),
+        help_text="The Drive of the VM e.g. Drive 1",
+    )
+    letter = CharField(
+        required=False,
+        label="Partition Letter",
+        help_text="The device name e.g. /dev/sdc1",
+    )
+    size = FloatField(
+        label="Size (GB)",
+        help_text="The size of the partition e.g. 25",
+        validators=[MinValueValidator(0.0)],
+    )
+    fs_type = DynamicModelChoiceField(
+        required=False,
+        queryset=Filesystem.objects.all(),
+        label="Filesystem Name",
+        widget=APISelect(
+            attrs={"data-url": reverse_lazy("plugins-api:netbox_storage-api:filesystem-list")}
+        ),
+        help_text="The Filesystem of the Volume e.g. ext4",
+    )
+    mountpoint = CharField(
+        required=False,
+        label="Mountpoint",
+        help_text="The mounted point of the volume e.g. /var/lib/docker",
+    )
+    fs_options = CharField(
+        required=False,
+        label="FS Options",
+        help_text="The mounted point of the volume e.g. /var/lib/docker",
+    )
+    description = CharField(
+        required=False,
+        label="Description",
+        help_text="Short Description e.g. Partition 1 on SSD Cluster",
+    )
+
+    fieldsets = (
+        (
+            "Select drive",
+            (
+                "drive",
+            ),
+        ),
+        (
+            "Partition Details",
+            (
+                "size",
+                'letter',
+                'fs_type'
+            ),
+        ),
+    )
+
+    class Meta:
+        model = Partition
+
+        fields = (
+            'drive', 'size', 'fs_type', 'letter'
+        )
